#!/bin/bash
#
# -----------------------------------------------------------------------------
# Phoenix start script.
#
# Author: Alexis Agahi <alag@users.sourceforge.net>
#         Peter Donald <peter at apache.org>
#
# Environment Variable Prequisites
#
#   PHOENIX_OPTS       (Optional) Java runtime options used when the command is 
#                      executed.
#
#   PHOENIX_TMPDIR     (Optional) Directory path location of temporary directory
#                      the JVM should use (java.io.tmpdir).  Defaults to
#                      $CATALINA_BASE/temp.
#
#   JAVA_HOME          Must point at your Java Development Kit installation.
#
#   PHOENIX_JVM_OPTS   (Optional) Java runtime options used when the command is 
#                       executed.
#
# -----------------------------------------------------------------------------

usage()
{
    echo "Usage: $0 {start|stop|run|restart|check}"
    exit 1
}

[ $# -gt 0 ] || usage

##################################################
# Get the action & configs
##################################################

ACTION=$1
shift
ARGS="$*"

# Source runtime options.
eval "`/opt/collabnet/teamforge/runtime/scripts/options-to-shell-variables.py`"

## Set PHOENIX_JVM_OPTS
. $RUNTIME_DIR/conf/set-env.sh

# Get standard environment variables
PHOENIX_HOME=$JAMES_HOME
RUNTIME_DIR=$RUNTIME_DIR
RUNTIME_SCRIPTS=$RUNTIME_DIR/scripts
PHOENIX_LOG=$LOG_DIR/phoenix/phoenix.log

# Export Obfuscation variables
export OBFUSCATION_KEY
export OBFUSCATION_PREFIX

# Checking for JAVA_HOME is required on *nix due
# to some distributions stupidly including kaffe in /usr/bin
if [ "$JAVA_HOME" = "" ] ; then
  echo "ERROR: JAVA_HOME not found in your environment."
  echo
  echo "Please, set the JAVA_HOME variable in your environment to match the"
  echo "location of the Java Virtual Machine you want to use."
  exit 1
fi

# ----- Execute The Requested Command -----------------------------------------

echo "Using PHOENIX_HOME:   $PHOENIX_HOME"
echo "Using PHOENIX_TMPDIR: $PHOENIX_TMPDIR"
echo "Using JAVA_HOME:      $JAVA_HOME"

# Uncomment to get enable remote debugging
# DEBUG="-Xdebug -Xrunjdwp:transport=dt_socket,address=8000,server=y,suspend=y"
#
# Command to overide JVM ext dir
#
# This is needed as some JVM vendors do foolish things
# like placing jaxp/jaas/xml-parser jars in ext dir
# thus breaking Phoenix
#
JVM_EXT_DIRS="$PHOENIX_HOME/lib:$PHOENIX_HOME/tools/lib:$JAVA_HOME/lib/ext"
JVM_OPTS="-Djava.ext.dirs=$JVM_EXT_DIRS"


if [ "$PHOENIX_SECURE" != "false" ] ; then
  # Make phoenix run with security manager enabled
  JVM_OPTS="$JVM_OPTS -Djava.security.manager"
fi

# Get the run cmd
RUN_CMD="$JAVA_HOME/bin/java $JVM_OPTS \
    $JVM_OPTS \
    $DEBUG \
    -Djava.security.policy=jar:file:"$PHOENIX_HOME"/bin/phoenix-loader.jar!/META-INF/java.policy \
    $PHOENIX_JVM_OPTS \
    -Dphoenix.home="$PHOENIX_HOME" \
    -Djava.io.tmpdir="$PHOENIX_TMPDIR" \
    -jar "$PHOENIX_HOME/bin/phoenix-loader.jar" -l "$PHOENIX_LOG" -a "$RUNTIME_DIR"/james/apps/ \
    -w "$PHOENIX_WORKDIR""


#####################################################
# Find a location for the phoenix console
#####################################################
PHOENIX_CONSOLE="$JAMES_LOG_DIR/phoenix.console"
if [  -z "$PHOENIX_CONSOLE" ]
then
  if [ -w /dev/console ]
  then
    PHOENIX_CONSOLE=/dev/console
  else
    PHOENIX_CONSOLE=/dev/tty
  fi
fi

PHOENIX_PID=/opt/collabnet/teamforge/run/phoenix.pid

#####################################################
# Action!
#####################################################

case "$ACTION" in
  start)
        echo "Starting Phoenix: "

        if [ -f $PHOENIX_PID ]
        then
            if ps -p `cat $PHOENIX_PID ` >/dev/null 2>/dev/null
            then
                echo "Already Running!!"
                # Don't barf if stale pid found, just restart
                $0 stop
                sleep 5
            fi
        fi

        echo "STARTED Phoenix `date` (as $JAMES_USER)" >> $PHOENIX_CONSOLE

        # Using 'su -m' to pass obfuscation environment.
        su -m $JAMES_USER -c "nohup sh -c \"exec $RUN_CMD | $RUNTIME_SCRIPTS/timestamp >>$PHOENIX_CONSOLE 2>&1\" >/dev/null 2>&1 & echo "\$!" > $PHOENIX_PID"
        echo "Phoenix running pid="`cat $PHOENIX_PID`
        ;;

  stop)
        PID=`cat $PHOENIX_PID 2>/dev/null`
        echo "Shutting down Phoenix: $PID"
        for cpid in $(ps -o pid= --ppid $PID)
        do
          kill -9 $cpid > /dev/null 2>&1
        done
        kill -9 $PID > /dev/null 2>&1
        rm -f $PHOENIX_PID
        echo "STOPPED `date`" >>$PHOENIX_CONSOLE
        ;;

  restart)
        $0 stop $*
        sleep 5
        $0 start $*
        ;;

  supervise)
       #
       # Under control of daemontools supervise monitor which
       # handles restarts and shutdowns via the svc program.
       #
         exec $RUN_CMD
         ;;

  run|demo)
        echo "Running Phoenix: "

        if [ -f $PHOENIX_PID ]
        then
            echo "Already Running!!"
            exit 1
        fi

        exec $RUN_CMD
        ;;
        
  check)
        echo "Checking arguments to Phoenix: "
        echo "PHOENIX_HOME:     $PHOENIX_HOME"
        echo "PHOENIX_TMPDIR:   $PHOENIX_TMPDIR"
        echo "PHOENIX_JVM_OPTS: $PHOENIX_JVM_OPTS"
        echo "JAVA_HOME:        $JAVA_HOME"
        echo "JVM_OPTS:         $JVM_OPTS"
        echo "CLASSPATH:        $CLASSPATH"
        echo "RUN_CMD:          $RUN_CMD"
        echo

        if [ -f $PHOENIX_PID ]
        then
            if ps -p `cat $PHOENIX_PID ` >/dev/null 2>/dev/null
            then
                echo "Phoenix running pid="`cat $PHOENIX_PID`
                exit 0
            fi
        fi
        exit 1
        ;;
        
*)
        usage
        ;;
esac

exit 0




